"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getOrCreateStore = exports.BaseStore = void 0;

var _utils = require("./utils");

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var __NEXT_MOBX_STORE__ = '__NEXT_MOBX_STORE__';

var BaseStore = function BaseStore() {
  var props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  _classCallCheck(this, BaseStore);

  for (var prop in props) {
    // Convert JSON string to Map string for client
    this[prop] = (0, _utils.jsonToMap)(props[prop]);
  }
};

exports.BaseStore = BaseStore;

var makeInitializeStore = function makeInitializeStore(Store) {
  var store = null;
  return function () {
    var initialState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    if (_utils.isServer) {
      return new Store(initialState);
    }

    if (store === null) {
      store = new Store(initialState);
    }

    return store;
  };
};

var getOrCreateStore = function getOrCreateStore(storeKeyName, Store) {
  return function (initialState) {
    // Convert Map to JSON string for client
    if (initialState) {
      try {
        for (var itemState in initialState) {
          try {
            var dataMap = initialState[itemState];

            if (dataMap.toJS() instanceof Map) {
              initialState[itemState] = (0, _utils.mapToJson)(dataMap);
            }
          } catch (e) {}
        }
      } catch (e) {}
    }

    var initializeStore = makeInitializeStore(Store); // Always make a new store if server, otherwise state is shared between requests

    if (_utils.isServer) {
      return initializeStore(initialState);
    }

    window[__NEXT_MOBX_STORE__] = window[__NEXT_MOBX_STORE__] || {}; // Create store if unavailable on the client and set it on the window object

    if (!window[__NEXT_MOBX_STORE__][storeKeyName]) {
      window[__NEXT_MOBX_STORE__][storeKeyName] = initializeStore(initialState);
    }

    return window[__NEXT_MOBX_STORE__][storeKeyName];
  };
};

exports.getOrCreateStore = getOrCreateStore;
//# sourceMappingURL=index.js.map